#!/usr/bin/env python

"""
Simple routine to convert IPAC-format folded light curves (from the NStED
periodogram generator) to a format suitable for importing into Binary Maker 3.
JvE, July 2010.

USEAGE:
python ipaclc2bm.py INPUTFILE [OUTPUTFILE]

INPUTS:
  - INPUTFILE -- filename of an ascii-format folded lightcurve as output by the IPAC periodogram service.

OUTPUTS:
  - Writes a file converted to the '.nrm' ascii format required for importing into Binary Maker 3. Filename is OUTPUTFILE if provided, otherwise INPUTFILE.nrm 

"""


import numpy as np
import os
from optparse import OptionParser


#If started up from the command line:

if __name__ == "__main__":

    #Parse any command line options
    usage = ("Usage: %prog INPUTFILE [OUTPUTFILE]")
    parser = OptionParser(usage = usage)
    #parser.add_option("-o", "--outputfile", type="string", default = 'dummy',
    #                  help= "Output filename (default = FILENAME+'nrm')",
    #                  dest="outputfile")

    (options,args) = parser.parse_args()
    if len(args) == 0: parser.error("Must provide input filename.")
    elif len(args) == 1:
        inputfile = args[0]
        outputfile = args[0]+'.nrm'
    elif len(args) == 2:
        inputfile = args[0]
        outputfile = args[1]
    else: parser.error("Too many command line arguments.")
    if not os.access(inputfile, os.F_OK):
        parser.error("Input file not found: "+inputfile)

    
    #Read in the IPAC-format light curve file
    # - read in all lines of format [space, number, space, number, space, number]
    data = np.fromregex(inputfile, "\s+([.\d]+)\s+([.\d]+)\s+([.\d]+)",
                        dtype=[('mjd','f8'),('flux','f8'),('phase','f8')])

    #Trim off phase repetition
    phase = data['phase'][data['phase'] < 1.0]
    flux = data['flux'][data['phase'] < 1.0]

    #Normalise the flux
    normflux = flux/np.nanmax(flux)

    #Set phase = 0 at minimum of light curve
    phaseatminflux = phase[np.argmin(flux)]
    #Modulo 1 to put back in range 0--1:
    shiftedphase = (phase - phaseatminflux + 1.0 ) % 1.0 

    #Resort everything into ascending phase order
    order = np.argsort(shiftedphase)
    shiftedphase = shiftedphase[order]
    normflux = normflux[order]

    #Make a new array of the results as required for the output file:
    outputdata = np.array([shiftedphase, normflux]).transpose()

    #Save the results to a plain text file
    np.savetxt(outputfile, outputdata, delimiter=' ', fmt='%0.8f %0.8f')

    print 'Output saved to file: '+outputfile
